@@ -1,6 +1,6 @@
 package GFX::Enhancer::SingleLineEnhancer;
 
-### project a single line from e.g. a scanned in line
+### project a single line from e.g. a scanned in line (with a RL scanner)
 
 sub new {
 	my ($class) = @_;
@@ -12,7 +12,7 @@ sub new {
 	bless $self, $class;
 }
 
-sub process {
+sub filter {
 	my ($self, $imgrepr) = @_; 
 
 	### points are PNGRGBAs
